# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [1.0.0] - 2025-12-21

### Added
- Initial release

---

[Unreleased]: https://github.com/kupolak/nukat/compare/v1.0.0...HEAD
[1.0.0]: https://github.com/kupolak/nukat/releases/tag/v1.0.0
